@@ -25,11 +25,13 @@ from collections import Counter
 import pandas as pd
 import pkg_resources
 import requests
-from argofloats import argofloats
 from bs4 import BeautifulSoup
 from dateutil.relativedelta import *
+from natsort import natsorted
 from rapidfuzz import fuzz
 
+from .argofloats import argoexp
+
 headers = {
     "authority": "ocean-systems.uc.r.appspot.com",
     "sec-ch-ua": '" Not A;Brand";v="99", "Chromium";v="96", "Google Chrome";v="96"',
@@ -342,13 +344,25 @@ def sitelive_from_parser(args):
 
 
 # Get daily data for a site
-def site_daily(delta, sid, dtype):
-    d = datetime.datetime.utcnow()
-    current_utc = d.strftime("%Y-%m-%dT%H:%M:%SZ")
-    if delta is None:
-        delta = 3
-    past_utc = d + relativedelta(months=-delta)
-    past_utc = past_utc.strftime("%Y-%m-%dT%H:%M:%SZ")
+def site_daily(delta, sid, dtype, fpath, start, end):
+    if start and end is not None:
+        start = datetime.datetime.strptime(start, "%Y-%m-%d")
+        end = datetime.datetime.strptime(end, "%Y-%m-%d")
+        past_utc = start.strftime("%Y-%m-%dT%H:%M:%SZ")
+        current_utc = end.strftime("%Y-%m-%dT%H:%M:%SZ")
+    else:
+        d = datetime.datetime.utcnow()
+        current_utc = d.strftime("%Y-%m-%dT%H:%M:%SZ")
+        if delta is None:
+            delta = 3
+        past_utc = d + relativedelta(months=-int(delta))
+        past_utc = past_utc.strftime("%Y-%m-%dT%H:%M:%SZ")
+    response = requests.get(
+        f"https://ocean-systems.uc.r.appspot.com/api/sites/{sid}")
+    if response.status_code == 200:
+        resp = response.json()["polygon"]["coordinates"]
+        lng = resp[0]
+        lat = resp[1]
     print(f"Daily data from {past_utc} to {current_utc} for site {sid}")
     params = {
         "start": past_utc,
@@ -370,6 +384,7 @@ def site_daily(delta, sid, dtype):
         params=params,
     )
     if response.status_code == 200:
+        overall = []
         for resp in response.json():
             if dset is not None:
                 ext = {
@@ -383,9 +398,23 @@ def site_daily(delta, sid, dtype):
                           value in resp.items() if key == "date"}
                 combined = ext_dt.copy()
                 combined.update(ext)
-                print(json.dumps(combined, indent=2))
+                overall.append(combined)
             else:
-                print(json.dumps(resp, indent=2))
+                overall.append(resp)
+        if fpath is not None:
+            if dtype is None:
+                dtype = "overall"
+            fname = os.path.join(fpath, f"spotter_{dtype}_{sid}.csv")
+            df = pd.DataFrame(overall)
+            print(f"Exporting daily data to {fname}")
+            if lat and lng is not None:
+                df["latitude"] = lat
+                df["longitude"] = lng
+            df.dropna(axis=1, how="all", inplace=True)
+            df = df.loc[:, (df != 0).any(axis=0)]
+            df.to_csv(fname, index=False)
+        else:
+            print(json.dumps(overall, indent=2))
     else:
         print(
             f"Daily date fetch failed with error: {response.status_code} & {response.text}"
@@ -393,17 +422,30 @@ def site_daily(delta, sid, dtype):
 
 
 def sitedaily_from_parser(args):
-    site_daily(sid=args.sid, delta=args.months, dtype=args.dtype)
+    site_daily(
+        sid=args.sid,
+        delta=args.months,
+        dtype=args.dtype,
+        fpath=args.fpath,
+        start=args.start,
+        end=args.end,
+    )
 
 
 # Function to export time series data from site
-def site_timeseries(delta, sid, dtype, fpath):
-    d = datetime.datetime.utcnow()
-    current_utc = d.strftime("%Y-%m-%dT%H:%M:%SZ")
-    if delta is None:
-        delta = 3
-    past_utc = d + relativedelta(months=-int(delta))
-    past_utc = past_utc.strftime("%Y-%m-%dT%H:%M:%SZ")
+def site_timeseries(delta, sid, dtype, fpath, start, end):
+    if start and end is not None:
+        start = datetime.datetime.strptime(start, "%Y-%m-%d")
+        end = datetime.datetime.strptime(end, "%Y-%m-%d")
+        past_utc = start.strftime("%Y-%m-%dT%H:%M:%SZ")
+        current_utc = end.strftime("%Y-%m-%dT%H:%M:%SZ")
+    else:
+        d = datetime.datetime.utcnow()
+        current_utc = d.strftime("%Y-%m-%dT%H:%M:%SZ")
+        if delta is None:
+            delta = 3
+        past_utc = d + relativedelta(months=-int(delta))
+        past_utc = past_utc.strftime("%Y-%m-%dT%H:%M:%SZ")
     print(f"Time series from {past_utc} to {current_utc}")
 
     response = requests.get(
@@ -432,33 +474,38 @@ def site_timeseries(delta, sid, dtype, fpath):
     else:
         print("Datatype is not supported")
 
-    params = {"start": past_utc, "end": current_utc,
-              "metrics": metrics, "hourly": True}
+    params = {
+        "start": past_utc,
+        "end": current_utc,
+        "metrics": metrics,
+        "hourly": "true",
+    }
 
     response = requests.get(
         f"https://ocean-systems.uc.r.appspot.com/api/time-series/sites/{sid}",
         headers=headers,
-        params=params,
+        params=json.dumps(params),
     )
+    metric_list = []
     if response.status_code == 200:
         resp = response.json()
-        for metric in metrics.split(","):
-            if resp["noaa"][metric]:
-                print(f"Processing noaa_{metric}_{sid}")
-                fname = os.path.join(fpath, f"spotter_{metric}_{sid}.csv")
-                df = pd.DataFrame(resp["noaa"][metric])
-                if lat and lng is not None:
-                    df["latitude"] = lat
-                    df["longitude"] = lng
-                df.to_csv(fname, index=False)
-            if resp["spotter"][metric]:
-                print(f"Processing spotter_{metric}_{sid}")
-                fname = os.path.join(fpath, f"spotter_{metric}_{sid}.csv")
-                df = pd.DataFrame(resp["spotter"][metric])
-                if lat and lng is not None:
-                    df["latitude"] = lat
-                    df["longitude"] = lng
-                df.to_csv(fname, index=False)
+        for metric in resp:
+            metric_list.append(metric)
+        if dtype is not None and dtype in metric_list:
+            metric_list = [dtype]
+        for metric in natsorted(metric_list):
+            print(f"Processing spotter_{metric}_{sid}")
+            fname = os.path.join(fpath, f"spotter_{metric}_{sid}.csv")
+            try:
+                df = pd.DataFrame(resp[metric]["spotter"]["data"])
+            except Exception as error:
+                df = pd.DataFrame(resp[metric]["noaa"]["data"])
+            if lat and lng is not None:
+                df["latitude"] = lat
+                df["longitude"] = lng
+            df.dropna(axis=1, how="all", inplace=True)
+            df = df.loc[:, (df != 0).any(axis=0)]
+            df.to_csv(fname, index=False)
     else:
         print(
             f"Time series failed with error: {response.status_code} & {response.text}"
@@ -466,8 +513,14 @@ def site_timeseries(delta, sid, dtype, fpath):
 
 
 def timeseries_from_parser(args):
-    site_timeseries(sid=args.sid, delta=args.months,
-                    dtype=args.dtype, fpath=args.fpath)
+    site_timeseries(
+        sid=args.sid,
+        delta=args.months,
+        dtype=args.dtype,
+        fpath=args.fpath,
+        start=args.start,
+        end=args.end,
+    )
 
 
 # Function to export time series data from site
@@ -483,7 +536,7 @@ def site_argofloats(sid, fpath, start, end, radius):
             f"Failed to fetch {sid} coordinates with error: {response.status_code}"
         )
     try:
-        argofloats.argoexp(
+        argoexp(
             fpath=fpath,
             lat=lat,
             lng=lng,
@@ -578,11 +631,22 @@ def main(args=None):
     optional_named = parser_sitedaily.add_argument_group(
         "Optional named arguments")
     optional_named.add_argument(
-        "--months", help="Total number of months from today", default=None
+        "--months",
+        help="Total number of months in the past from today (default=1)",
+        default=None,
+    )
+    optional_named.add_argument(
+        "--start", help="Start date for daily data in format YYYY-MM-DD", default=None
+    )
+    optional_named.add_argument(
+        "--end", help="End date for daily data in format YYYY-MM-DD", default=None
     )
     optional_named.add_argument(
         "--dtype", help="Data type: wind/wave/temp", default=None
     )
+    optional_named.add_argument(
+        "--fpath", help="Full path to folder to export daily data as CSV", default=None
+    )
     parser_sitedaily.set_defaults(func=sitedaily_from_parser)
 
     parser_timeseries = subparsers.add_parser(
@@ -596,7 +660,15 @@ def main(args=None):
     optional_named = parser_timeseries.add_argument_group(
         "Optional named arguments")
     optional_named.add_argument(
-        "--months", help="Total number of months from today", default=None
+        "--months",
+        help="Total number of months in the past from today (default=3)",
+        default=None,
+    )
+    optional_named.add_argument(
+        "--start", help="Start date for daily data in format YYYY-MM-DD", default=None
+    )
+    optional_named.add_argument(
+        "--end", help="End date for daily data in format YYYY-MM-DD", default=None
     )
     optional_named.add_argument(
         "--dtype",
